
From: Christoph Hellwig <hch@lst.de>

The only common field in irq_cpustat is __softirq_pending, i386 and ppc
have some of their own.

Remove all unused obsolete fields from various architectures.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/asm-alpha/hardirq.h     |    3 ---
 25-akpm/include/asm-arm26/hardirq.h     |    4 ----
 25-akpm/include/asm-cris/hardirq.h      |    4 ----
 25-akpm/include/asm-h8300/hardirq.h     |    2 --
 25-akpm/include/asm-m32r/hardirq.h      |    2 --
 25-akpm/include/asm-m68knommu/hardirq.h |    2 --
 25-akpm/include/asm-parisc/hardirq.h    |    3 ---
 25-akpm/include/asm-ppc64/hardirq.h     |    1 -
 25-akpm/include/asm-v850/hardirq.h      |    2 --
 9 files changed, 23 deletions(-)

diff -puN include/asm-alpha/hardirq.h~remove-unused-irq_cpustat-fields include/asm-alpha/hardirq.h
--- 25/include/asm-alpha/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.869338024 -0800
+++ 25-akpm/include/asm-alpha/hardirq.h	2004-11-15 00:05:42.883335896 -0800
@@ -9,9 +9,6 @@
 /* entry.S is sensitive to the offsets of these fields */
 typedef struct {
 	unsigned long __softirq_pending;
-	unsigned int __syscall_count;
-	unsigned long idle_timestamp;
-	struct task_struct * __ksoftirqd_task;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-arm26/hardirq.h~remove-unused-irq_cpustat-fields include/asm-arm26/hardirq.h
--- 25/include/asm-arm26/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.870337872 -0800
+++ 25-akpm/include/asm-arm26/hardirq.h	2004-11-15 00:05:42.884335744 -0800
@@ -7,10 +7,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __local_irq_count;
-	unsigned int __local_bh_count;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task; /* waitqueue is too large */
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-cris/hardirq.h~remove-unused-irq_cpustat-fields include/asm-cris/hardirq.h
--- 25/include/asm-cris/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.872337568 -0800
+++ 25-akpm/include/asm-cris/hardirq.h	2004-11-15 00:05:42.884335744 -0800
@@ -9,10 +9,6 @@
 /* entry.S is sensitive to the offsets of these fields */
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __local_irq_count;
-	unsigned int __local_bh_count;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task; /* waitqueue is too large */
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h> /* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-h8300/hardirq.h~remove-unused-irq_cpustat-fields include/asm-h8300/hardirq.h
--- 25/include/asm-h8300/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.873337416 -0800
+++ 25-akpm/include/asm-h8300/hardirq.h	2004-11-15 00:05:42.884335744 -0800
@@ -9,8 +9,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-m32r/hardirq.h~remove-unused-irq_cpustat-fields include/asm-m32r/hardirq.h
--- 25/include/asm-m32r/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.875337112 -0800
+++ 25-akpm/include/asm-m32r/hardirq.h	2004-11-15 00:05:42.884335744 -0800
@@ -7,8 +7,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task; /* waitqueue is too large */
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-m68knommu/hardirq.h~remove-unused-irq_cpustat-fields include/asm-m68knommu/hardirq.h
--- 25/include/asm-m68knommu/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.876336960 -0800
+++ 25-akpm/include/asm-m68knommu/hardirq.h	2004-11-15 00:05:42.885335592 -0800
@@ -7,8 +7,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-parisc/hardirq.h~remove-unused-irq_cpustat-fields include/asm-parisc/hardirq.h
--- 25/include/asm-parisc/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.877336808 -0800
+++ 25-akpm/include/asm-parisc/hardirq.h	2004-11-15 00:05:42.885335592 -0800
@@ -21,9 +21,6 @@
 
 typedef struct {
 	unsigned long __softirq_pending; /* set_bit is used on this */
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task;
-	unsigned long idle_timestamp;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-ppc64/hardirq.h~remove-unused-irq_cpustat-fields include/asm-ppc64/hardirq.h
--- 25/include/asm-ppc64/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.879336504 -0800
+++ 25-akpm/include/asm-ppc64/hardirq.h	2004-11-15 00:05:42.885335592 -0800
@@ -14,7 +14,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	struct task_struct * __ksoftirqd_task;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
diff -puN include/asm-v850/hardirq.h~remove-unused-irq_cpustat-fields include/asm-v850/hardirq.h
--- 25/include/asm-v850/hardirq.h~remove-unused-irq_cpustat-fields	2004-11-15 00:05:42.880336352 -0800
+++ 25-akpm/include/asm-v850/hardirq.h	2004-11-15 00:05:42.885335592 -0800
@@ -7,8 +7,6 @@
 
 typedef struct {
 	unsigned int __softirq_pending;
-	unsigned int __syscall_count;
-	struct task_struct * __ksoftirqd_task;
 } ____cacheline_aligned irq_cpustat_t;
 
 #include <linux/irq_cpustat.h>	/* Standard mappings for irq_cpustat_t above */
_
